"""
The core celestial_tools package is broken out into two pieces.

client - the target emebedded device

server - host to serve files, etc to  the target device
"""

from celestial_tools import client
